timeseria.exceptions
====================

.. automodule:: timeseria.exceptions

   
   
   

   
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      ConsistencyException
      FloatConversionError
      NoDataException
      NonContiguityError
      NotFittedError
   
   



